[osmose-emulator] 01/01: Updated file

Carlos Donizete Froes coringao-guest at moszumanska.debian.org
Thu Oct 19 15:24:07 UTC 2017


This is an automated email from the git hooks/post-receive script.

coringao-guest pushed a commit to branch master
in repository osmose-emulator.

commit 820700a37d19313f88745f65301f5ad11ab8968e
Author: Carlos Donizete Froes <coringao at riseup.net>
Date:   Thu Oct 19 13:23:37 2017 -0200

    Updated file
---
 src/AnsiColorTerminal.h           | 20 ++++----------------
 src/BasicTypes.h                  | 13 ++-----------
 src/Bits.h                        |  7 +++++--
 src/DebugEventListener.h          | 23 ++++++-----------------
 src/DebugEventThrower.cpp         | 23 ++++-------------------
 src/DebugEventThrower.h           | 18 ++++--------------
 src/Definitions.h                 |  5 ++++-
 src/EmulationThread.cpp           | 24 ++++--------------------
 src/EmulationThread.h             | 11 ++---------
 src/FIFOSoundBuffer.cpp           | 16 ++++------------
 src/FIFOSoundBuffer.h             | 17 +++++------------
 src/IOMapper.cpp                  | 16 ++++------------
 src/IOMapper.h                    | 16 ++++------------
 src/IOMapper_GG.cpp               | 16 ++++------------
 src/IOMapper_GG.h                 | 15 ++++-----------
 src/Joystick.cpp                  | 15 ++-------------
 src/Joystick.h                    | 15 ++-------------
 src/KeyMapper.cpp                 | 12 ++----------
 src/KeyMapper.h                   | 12 ++----------
 src/MemoryMapper.cpp              | 21 ++++++---------------
 src/MemoryMapper.h                | 21 ++++++---------------
 src/Opc_cbxx.cpp                  | 20 +++++---------------
 src/Opc_dd.cpp                    | 25 +++++++------------------
 src/Opc_ddcb.cpp                  | 20 +++++---------------
 src/Opc_ed.cpp                    | 18 +++++-------------
 src/Opc_fd.cpp                    | 21 +++++----------------
 src/Opc_fdcb.cpp                  | 21 +++++----------------
 src/Opc_std.cpp                   | 21 +++++----------------
 src/Options.cpp                   | 26 +++++++++-----------------
 src/Options.h                     | 20 ++++++--------------
 src/OsmoseConfigurationFile.cpp   | 15 ++++-----------
 src/OsmoseConfigurationFile.h     | 15 ++++-----------
 src/OsmoseCore.cpp                | 21 ++++++---------------
 src/OsmoseCore.h                  | 21 ++++++---------------
 src/OsmoseEmulationThread.cpp     | 16 ++++------------
 src/OsmoseEmulationThread.h       | 16 +++++-----------
 src/OsmoseGUI.cpp                 | 32 +++++++++++++-------------------
 src/OsmoseGUI.h                   | 14 +++-----------
 src/OsmoseResources.qrc           |  2 +-
 src/Pthreadcpp.cpp                | 17 +++++------------
 src/Pthreadcpp.h                  | 15 ++++-----------
 src/QGLImage.cpp                  | 31 +++++++++++--------------------
 src/QGLImage.h                    | 23 ++++-------------------
 src/QLogWindow.cpp                | 15 ++++-----------
 src/QLogWindow.h                  | 15 ++++-----------
 src/QOsmoseConfiguration.cpp      | 16 +++++-----------
 src/QOsmoseConfiguration.h        | 15 ++++-----------
 src/RomSpecificOption.cpp         | 21 ++++++---------------
 src/RomSpecificOption.h           | 21 ++++++---------------
 src/SN76489.cpp                   | 20 ++++++--------------
 src/SN76489.h                     | 20 ++++++--------------
 src/SaveState.h                   | 20 ++++++--------------
 src/SmsDebugger.cpp               | 20 ++++++--------------
 src/SmsDebugger.h                 | 20 ++++++--------------
 src/SmsEnvironment.cpp            | 13 ++++++++-----
 src/SmsEnvironment.h              | 11 +++++++----
 src/SoundThread.cpp               | 12 +++---------
 src/SoundThread.h                 | 16 +++++-----------
 src/TGAWriter.cpp                 | 17 ++++-------------
 src/TGAWriter.h                   | 17 ++++-------------
 src/VDP.cpp                       | 20 ++++++--------------
 src/VDP.h                         | 20 ++++++--------------
 src/VDP_GG.cpp                    | 20 ++++++--------------
 src/VDP_GG.h                      | 20 ++++++--------------
 src/Version.h                     |  7 +++++--
 src/WaveWriter.cpp                | 21 ++++++---------------
 src/WaveWriter.h                  | 21 ++++++---------------
 src/WhiteNoiseEmulationThread.cpp | 15 ++++-----------
 src/WhiteNoiseEmulationThread.h   | 16 +++++-----------
 src/Z80.cpp                       | 22 ++++++----------------
 src/Z80.h                         | 19 +++++--------------
 src/main.cpp                      |  3 ++-
 72 files changed, 355 insertions(+), 904 deletions(-)

diff --git a/src/AnsiColorTerminal.h b/src/AnsiColorTerminal.h
index 21f19e2..1054f2a 100644
--- a/src/AnsiColorTerminal.h
+++ b/src/AnsiColorTerminal.h
@@ -1,6 +1,6 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -18,22 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: AnsiTer,inalColors.h
- * Project: Osmose emulator.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Description: These MACROS allows the program to output colored strings on
- * the terminal. Note that only basic coloring is handled, not the full escape
- * sequences defined by the norm. SO Bold chars, video inverse and blinking
- * things do not work.
- *
- * Note that USE_ISO_IEC_6429 must be define in order to work. Undefine this
- * setting for non ISO6429 compliant terminal (ms win).
- *
- * Author: Vedder Bruno
- * Date: 12/12/2007
- * URL: http://bcz.asterope.fr
  */
- 
+
 #ifndef ANSI_TERMINAL_COLORS_H
 #define ANSI_TERMINAL_COLORS_H
 
diff --git a/src/BasicTypes.h b/src/BasicTypes.h
index c4207ca..4897c66 100644
--- a/src/BasicTypes.h
+++ b/src/BasicTypes.h
@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -17,18 +17,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File: BasicTypes.cpp
- *
- * Project: Osmose.
- *
- * Description: This file define shorter types used in Osmose.
  *
- * Author: Vedder Bruno
- * Date: 20/03/2006, 21h30 Malaisia.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * URL: http://bcz.asterope.fr/
  */
  
 #ifndef BASICTYPES_H
diff --git a/src/Bits.h b/src/Bits.h
index 681304c..2400593 100644
--- a/src/Bits.h
+++ b/src/Bits.h
@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -17,7 +17,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
-*/
+ *
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
+ *
+ */
 
 #ifndef BITS_H
 #define BITS_H
diff --git a/src/DebugEventListener.h b/src/DebugEventListener.h
index 3aed5ad..3f4af60 100644
--- a/src/DebugEventListener.h
+++ b/src/DebugEventListener.h
@@ -1,6 +1,6 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -18,26 +18,15 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: DebugEventListener.h
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Project: Osmose emulator.
- *
- * Description: This interface declares behaviour for Listening debug events.
- * It's done to help debugging SMS/GG hardware and Osmose code.
- * How it's used:
- * SmsDebugger or a logger for example implements the DebugEventListener
- * interface. The VDP, or any debugEventThrower will be attach to the
- * DebugEventListener. To throw debug event the thrower will use throwDebugEvent
- * method.
- * Author: Vedder Bruno
- *
- * Date: 16.11.2006 10:42:28
- *
- * URL: http://bcz.asterope.fr
  */
+
 #ifndef DEBUG_EVENT_LISTENER_H
 #define DEBUG_EVENT_LISTENER_H
 
+#include "DebugEventThrower.h"
+
 /* Debug Event types. */
 enum
 {
diff --git a/src/DebugEventThrower.cpp b/src/DebugEventThrower.cpp
index b6c5ec4..3eaf09c 100644
--- a/src/DebugEventThrower.cpp
+++ b/src/DebugEventThrower.cpp
@@ -1,6 +1,6 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -18,20 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: DebugEventThrower.cpp
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Project: Osmose emulator.
- *
- * Description: This interface declares behaviour for a thrower of debug events.
- * It's done to help debugging SMS/GG hardware and Osmose code.
- *
- * Author: Vedder Bruno
- *
- * Date: 16.11.2006 10:42:28
- *
- * URL: http://bcz.asterope.fr/
  */
- 
+
 #include "DebugEventThrower.h"
 
 void DebugEventThrower::attachDebugEventListener(DebugEventListener *el)
@@ -51,8 +41,3 @@ void DebugEventThrower::throwDebugEvent(int type,char *source, char *msg)
     }
 }
 
-
-
-
-
-
diff --git a/src/DebugEventThrower.h b/src/DebugEventThrower.h
index a402c32..324f434 100644
--- a/src/DebugEventThrower.h
+++ b/src/DebugEventThrower.h
@@ -1,6 +1,6 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -18,20 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: DebugEventThrower.h
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Project: Osmose emulator.
- *
- * Description: This interface declares behaviour for a thrower of debug events.
- * It's done to help debugging SMS/GG hardware and Osmose code.
- *
- * Author: Vedder Bruno
- *
- * Date: 16.11.2006 10:42:28
- *
- * URL: http://bcz.asterope.fr/
  */
- 
+
 #ifndef DEBUG_EVENT_THROWER_H
 #define DEBUG_EVENT_THROWER_H
 
diff --git a/src/Definitions.h b/src/Definitions.h
index bb2588f..7bea11e 100644
--- a/src/Definitions.h
+++ b/src/Definitions.h
@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -17,6 +17,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
+ *
  */
  
 #ifndef DEFINITIONS_H_
diff --git a/src/EmulationThread.cpp b/src/EmulationThread.cpp
index 9f64f3a..49ad2bd 100644
--- a/src/EmulationThread.cpp
+++ b/src/EmulationThread.cpp
@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -17,24 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : EmulationThread.cpp
- *
- * Description : This class provide basic EmulationThread feature. It can start
- * pause, resume the rendering code that is provided in emulateOneFrame() pure
- * virtual method. The setRefreshingPeriod() set the number of frame per second
- * that is wanted. emulatOneframe() is called accordingly. The setResolution()
- * method emits a newResolution() signal to the QGLimage object to inform it 
- * of a resolution change (e.g. emulated video mode switch). The texture buffer
- * videoBuffer is allocated accordingly.
- * This class MUST be inherited, and the derived class MUST provide the 
- * emulateOneFrame() function, which perform emulation task and fill the video
- * buffer.
- *
- * Author : B.Vedder
  *
- * Date : Fri May 21 14:05:52 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
@@ -50,7 +34,7 @@ EmulationThread::EmulationThread(QGLImage *qglimage) : screen(qglimage)
 	QObject::connect(this, SIGNAL(newResolution(int, int)), qglimage, SLOT(resolutionChanged(int, int)));
 	setResolution(qglimage->getTextureWidth(), qglimage->getTextureHeight());
 	emulationState = EMULATION_STOPPED;
-	
+
 	// Set default refresh slow arbitrary frequency.
 	setRefreshFrequency(1.0f);
 	done = false;
@@ -66,7 +50,7 @@ EmulationThread::~EmulationThread()
 
 /**
  * This method overrides QThread run(). It's the thread main method.
- * 
+ *
  * Return : None.
  */
 void EmulationThread::run()
diff --git a/src/EmulationThread.h b/src/EmulationThread.h
index 4d7a52c..e46c815 100644
--- a/src/EmulationThread.h
+++ b/src/EmulationThread.h
@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -17,15 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : EmulationThread.h
- *
- * Description :
- *
- * Author : B.Vedder
  *
- * Date : Fri May 21 14:05:52 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
diff --git a/src/FIFOSoundBuffer.cpp b/src/FIFOSoundBuffer.cpp
index e68e96b..0d88962 100644
--- a/src/FIFOSoundBuffer.cpp
+++ b/src/FIFOSoundBuffer.cpp
@@ -1,6 +1,6 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -18,18 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: FIFOSoundBuffer.cpp
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Project: Osmose emulator.
- *
- * Description: This class implements Circular sound buffer utility.
- *
- * Author: Vedder Bruno
- * Date: 12/07/2006, 20h00 Chile, 'Detroit de Magellan'
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #include "FIFOSoundBuffer.h"
 #include <stdio.h>
 
diff --git a/src/FIFOSoundBuffer.h b/src/FIFOSoundBuffer.h
index 0a76574..5acf10f 100644
--- a/src/FIFOSoundBuffer.h
+++ b/src/FIFOSoundBuffer.h
@@ -1,6 +1,6 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -18,17 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: FIFOSoundBuffer.h
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Project: Osmose emulator.
- *
- * Description: This class define Circular sound buffer utility.
- *
- * Author: Vedder Bruno
- * Date: 12/07/2006, 20h00 Chile, 'Detroit de Magellan'
- *
- * URL: http://bcz.asterope.fr
  */
+
 #ifndef FIFO_SOUND_BUFFER_H
 #define FIFO_SOUND_BUFFER_H
 #include "BasicTypes.h"
@@ -43,7 +36,7 @@ class FIFOSoundBuffer
         /* Destructor. */
         ~FIFOSoundBuffer()
         {
-            delete data_;
+            delete[] data_ ;
         }
 
         /* Write a value if buffer is not full. */
diff --git a/src/IOMapper.cpp b/src/IOMapper.cpp
index bb0255f..b85cdc5 100644
--- a/src/IOMapper.cpp
+++ b/src/IOMapper.cpp
@@ -1,6 +1,6 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -18,18 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: IOMapper.cpp
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Project: Osmose emulator.
- *
- * Description: This class will handle emulator input/output operation.
- *
- * Author: Vedder Bruno
- * Date: 08/10/2004, 18h00
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #include "IOMapper.h"
 #include "Bits.h"
 
diff --git a/src/IOMapper.h b/src/IOMapper.h
index 16701ec..3777034 100644
--- a/src/IOMapper.h
+++ b/src/IOMapper.h
@@ -1,6 +1,6 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -18,18 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: IOMapper.h
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Project: Osmose emulator.
- *
- * Description: This class will handle SMS emulator input/output operation.
- *
- * Author: Vedder Bruno
- * Date: 08/10/2004, 18h00
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #ifndef IO_MAPPER_H
 #define IO_MAPPER_H
 
diff --git a/src/IOMapper_GG.cpp b/src/IOMapper_GG.cpp
index e3fcec0..130fdeb 100644
--- a/src/IOMapper_GG.cpp
+++ b/src/IOMapper_GG.cpp
@@ -1,6 +1,6 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -18,18 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: IOMapper_GG.cpp
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Project: Osmose emulator.
- *
- * Description: This class will handle GAMEGEAR emulator input/output operation.
- *
- * Author: Vedder Bruno
- * Date: 08/10/2004, 18h00
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #include "IOMapper_GG.h"
 #include <stdlib.h>
 
diff --git a/src/IOMapper_GG.h b/src/IOMapper_GG.h
index 6068808..9ae0f03 100644
--- a/src/IOMapper_GG.h
+++ b/src/IOMapper_GG.h
@@ -1,6 +1,6 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -18,17 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: IOMapper_GG.h
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Project: Osmose emulator.
- *
- * Description: This class will handle GAMEGEAR emulator input/output operation.
- *
- * Author: Vedder Bruno
- * Date: 08/10/2004, 18h00
- *
- * URL: http://bcz.asterope.fr
  */
+
 #ifndef IO_MAPPER_GG_H
 #define IO_MAPPER_GG_H
 
diff --git a/src/Joystick.cpp b/src/Joystick.cpp
index 263cad3..c662f24 100644
--- a/src/Joystick.cpp
+++ b/src/Joystick.cpp
@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *
  * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
@@ -18,18 +18,7 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- *
- * File : Joystick.cpp
- *
- * Description : This class inherits from Thread and read, every
- * polling period, the device file given to it's constructor. If events
- * are detected, the listener joystickChanged method will be called.
- * Note that several events will generate several call to joystick
- * changed. There's only one listener at a time.
- *
- * Author : B.Vedder
- *
- * Date : Wed Dec 29 08:36:46 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
diff --git a/src/Joystick.h b/src/Joystick.h
index 8d508b9..c3ac43e 100644
--- a/src/Joystick.h
+++ b/src/Joystick.h
@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -17,19 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : Joystick.h
- *
- * Description : This class inherits from Thread and read, every
- * polling period, the device file given to it's constructor. If events
- * are detected, the listener joystickChanged method will be called.
- * Note that several events will generate several call to joystick 
- * changed. There's only one listener at a time.
- *
- * Author : B.Vedder
  *
- * Date : Wed Dec 29 08:36:46 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
diff --git a/src/KeyMapper.cpp b/src/KeyMapper.cpp
index df2487c..75652e0 100644
--- a/src/KeyMapper.cpp
+++ b/src/KeyMapper.cpp
@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -17,16 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : KeyMapper.cpp
- *
- * Description : This singleton is used to convert Qt::Key into const char *
- * representing the key. getKeyDescription (Qt::0x20) returns const char * ='space'.
- *
- * Author : B.Vedder
  *
- * Date : Fri Nov 26 10:55:13 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
diff --git a/src/KeyMapper.h b/src/KeyMapper.h
index 12bbe0c..5035477 100644
--- a/src/KeyMapper.h
+++ b/src/KeyMapper.h
@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -17,16 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : KeyMapper.h
- *
- * Description : This singleton is used to convert Qt::Key into const char *
- * representing the key. Qt::0x20 returns 'space'.
- *
- * Author : B.Vedder
  *
- * Date : Fri Nov 26 10:55:13 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
diff --git a/src/MemoryMapper.cpp b/src/MemoryMapper.cpp
index 7cc942b..959c66b 100644
--- a/src/MemoryMapper.cpp
+++ b/src/MemoryMapper.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,19 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: MemoryMapper.cpp
- *
- * Project: Osmose emulator.
- *
- * Description: This class will handle emulator read/write and bank
- * switching during emulation.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 02/10/2004, 18h00
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #include "MemoryMapper.h"
 #include "Options.h"
 #include "RomSpecificOption.h"
diff --git a/src/MemoryMapper.h b/src/MemoryMapper.h
index 59a7ff4..60ed809 100644
--- a/src/MemoryMapper.h
+++ b/src/MemoryMapper.h
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,19 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: MemoryMapper.h
- *
- * Project: Osmose emulator.
- *
- * Description: This class will handle emulator read/write and bank
- * switching during emulation.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 02/10/2004, 18h00
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #ifndef MEMORY_MAPPER_H
 #define MEMORY_MAPPER_H
 
diff --git a/src/Opc_cbxx.cpp b/src/Opc_cbxx.cpp
index 91a593d..5a22bd9 100644
--- a/src/Opc_cbxx.cpp
+++ b/src/Opc_cbxx.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,19 +17,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- * File: Opc_cbxx.cpp
- *
- * Project: Oldspark emulator.
- *
- * Description: This class implements all opcodes with 0xcb prefixes.
- * Timing is 100% Mame compliant.
- *
- * Note: 99% of this code has been generated.
  *
- * Author: Vedder Bruno
- * Date: 10/01/2006, Thailand, Laos Cambodia :-)
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * URL: http://bcz.asterope.fr
  */
 
 #include "Z80.h"
diff --git a/src/Opc_dd.cpp b/src/Opc_dd.cpp
index b17c62f..ce4539f 100644
--- a/src/Opc_dd.cpp
+++ b/src/Opc_dd.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,19 +18,8 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: Opc_dd.cpp
- *
- * Project: Oldspark emulator.
- *
- * Description: This class implements all opcodes with 0xdd prefixes.
- * Timing is 100% Mame compliant.
- *
- * Note: 99% of this code has been generated.
- *
- * Author: Vedder Bruno
- * Date: 10/01/2006, Thailand, Laos Cambodia :-)
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * URL: http://bcz.asterope.fr
  */
 
 #include "Z80.h"
@@ -297,7 +286,7 @@ void Z80::Opc_ddxx_63()
 /* LD IXH, IXH */
 void Z80::Opc_ddxx_64()
 {
-    IX = IX; // Do nothing;
+    IX = (IX); // Do nothing;
     cycleCount += 9;
 }
 
@@ -361,7 +350,7 @@ void Z80::Opc_ddxx_6c()
 /* LD IXL, IXL */
 void Z80::Opc_ddxx_6d()
 {
-    IX = IX; // Do nothing;
+    IX = (IX); // Do nothing;
     cycleCount += 9;
 }
 
diff --git a/src/Opc_ddcb.cpp b/src/Opc_ddcb.cpp
index 2d4b021..535c43f 100644
--- a/src/Opc_ddcb.cpp
+++ b/src/Opc_ddcb.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,19 +17,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- * File: Opc_ddcb.cpp
- *
- * Project: Oldspark emulator.
- *
- * Description: This class implements all opcodes with 0xddcb prefixes.
- * Timing is 100% Mame compliant.
- *
- * Note: 99% of this code has been generated.
  *
- * Author: Vedder Bruno
- * Date: 10/01/2006, Thailand, Laos Cambodia :-)
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * URL: http://bcz.asterope.fr
  */
 
 #include "Z80.h"
diff --git a/src/Opc_ed.cpp b/src/Opc_ed.cpp
index 481c744..b9ed766 100644
--- a/src/Opc_ed.cpp
+++ b/src/Opc_ed.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,17 +17,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- * File: Opc_ed.cpp
- *
- * Project: Osmose emulator.
- *
- * Description: This class implements all opcodes with 0xed prefixes.
- * Timing is not 100% Mame compliant (RETN RETI are not certain).
  *
- * Author: Vedder Bruno
- * Date: 10/01/2006, Thailand, Laos Cambodia :-)
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * URL: http://bcz.asterope.fr/
  */
 
 #include "Z80.h"
diff --git a/src/Opc_fd.cpp b/src/Opc_fd.cpp
index 9817b2e..b241245 100644
--- a/src/Opc_fd.cpp
+++ b/src/Opc_fd.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,19 +18,8 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: Opc_fd.cpp
- *
- * Project: Osmose emulator.
- *
- * Description: This class implements all opcodes with 0xfd prefixes.
- * Timing is 100% Mame compliant.
- *
- * Note: 99% of this code has been generated.
- *
- * Author: Vedder Bruno
- * Date: 10/01/2006, Thailand, Laos Cambodia :-)
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * URL: http://bcz.asterope.fr
  */
 
 #include "Z80.h"
diff --git a/src/Opc_fdcb.cpp b/src/Opc_fdcb.cpp
index f7ff937..9a026c8 100644
--- a/src/Opc_fdcb.cpp
+++ b/src/Opc_fdcb.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,19 +18,8 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: Opc_fdcb.cpp
- *
- * Project: Osmose emulator.
- *
- * Description: This class implements all opcodes with 0xfdcb prefixes.
- * Timing is 100% Mame compliant.
- *
- * Note: 99% of this code has been generated.
- *
- * Author: Vedder Bruno
- * Date: 10/01/2006, Thailand, Laos Cambodia :-)
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * URL: http://bcz.asterope.fr
  */
 
 #include "Z80.h"
diff --git a/src/Opc_std.cpp b/src/Opc_std.cpp
index c0f1348..4c2e9d8 100644
--- a/src/Opc_std.cpp
+++ b/src/Opc_std.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,20 +17,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- * File: Opc_std.cpp
- *
- * Project: Osmose emulator.
- *
- * Description: This class implements all opcodes without prefixes.
- * Timing is 100% Mame compliant. Methods here should be used through the jump table
- * "Z80::Opc_std[ opcode ]".
- *
- * Note: This table has no exec() method since cpu uses directly it's jump table.
  *
- * Author: Vedder Bruno
- * Date: 10/01/2006, Thailand, Laos Cambodia :-)
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * URL: http://bcz.asterope.fr
  */
 
 #include "Z80.h"
diff --git a/src/Options.cpp b/src/Options.cpp
index 888c87f..18d4528 100644
--- a/src/Options.cpp
+++ b/src/Options.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,25 +18,17 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: Options.cpp
- *
- * Project: Osmose emulator.
- *
- * Description: This file contains resets function for Options, and
- * emulator options. It's nothing else than default values.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 11/01/2005, 18h40
- *
- * URL: http://bcz.asterope.fr
- *****************************************************************************/
+ */
+
 #include "Options.h"
 #include "MemoryMapper.h"
 #include <cstring>
 
 // Global emulator options instance.
-Options opt; 
-EmulatorOptions      emu_opt; 
+Options opt;
+EmulatorOptions      emu_opt;
 
 void Options::reset()
 {
diff --git a/src/Options.h b/src/Options.h
index 9adca90..fa18e3f 100644
--- a/src/Options.h
+++ b/src/Options.h
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,18 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: Options.h
- *
- * Project: Osmose emulator.
- *
- * Description: This class is just a global variable receptor.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 11/01/2005, 18h40
- *
- * URL: http://bcz.asterope.fr/
  */
- 
+
 #ifndef OPTIONS_H
 #define OPTIONS_H
 
diff --git a/src/OsmoseConfigurationFile.cpp b/src/OsmoseConfigurationFile.cpp
index 7f18f18..ec97375 100644
--- a/src/OsmoseConfigurationFile.cpp
+++ b/src/OsmoseConfigurationFile.cpp
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,15 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : OsmoseConfigurationFile.cpp
- *
- * Description :
- *
- * Author : B.Vedder
  *
- * Date : Fri Nov 26 15:50:00 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
diff --git a/src/OsmoseConfigurationFile.h b/src/OsmoseConfigurationFile.h
index cfca8c3..61b41da 100644
--- a/src/OsmoseConfigurationFile.h
+++ b/src/OsmoseConfigurationFile.h
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,15 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : OsmoseConfigurationFile.h
- *
- * Description : This class handle $HOME .osmose.ini file.
- *
- * Author : B.Vedder
  *
- * Date : Fri Nov 26 15:50:00 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
diff --git a/src/OsmoseCore.cpp b/src/OsmoseCore.cpp
index df270a6..fc675ff 100644
--- a/src/OsmoseCore.cpp
+++ b/src/OsmoseCore.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,19 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: OsmoseCore.cpp
- *
- * Project: Osmose emulator.
- *
- * Description: This file contains Osmose main loop, handling keyboard, SDL
- * event, and hardware emulation.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 23/01/2005, 14h13
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #include "OsmoseCore.h"
 
 
diff --git a/src/OsmoseCore.h b/src/OsmoseCore.h
index 6bdae84..45e6969 100644
--- a/src/OsmoseCore.h
+++ b/src/OsmoseCore.h
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,19 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: OsmoseCore.h
- *
- * Project: Osmose emulator.
- *
- * Description: This file contains Osmose main loop, handling keyboard,
- * event, and hardware emulation.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 23/01/2005, 14h13
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #ifndef OSMOSE_CORE_H
 #define OSMOSE_CORE_H
 
diff --git a/src/OsmoseEmulationThread.cpp b/src/OsmoseEmulationThread.cpp
index 777b5fe..4e8a85d 100644
--- a/src/OsmoseEmulationThread.cpp
+++ b/src/OsmoseEmulationThread.cpp
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,21 +17,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : OsmoseEmulationThread.cpp
- *
- * Description :
  *
- * Author : B.Vedder
- *
- * Date : Thu May 27 14:20:27 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
 #include "OsmoseEmulationThread.h"
 
-
 /**
  * Constructor.
  */
diff --git a/src/OsmoseEmulationThread.h b/src/OsmoseEmulationThread.h
index e9ac70a..a90be0a 100644
--- a/src/OsmoseEmulationThread.h
+++ b/src/OsmoseEmulationThread.h
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,17 +17,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : OsmoseEmulationThread.h
- *
- * Description :
  *
- * Author : B.Vedder
- *
- * Date : Thu May 27 14:20:27 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
+
 #ifndef OSMOSE_EMULATION_THREAD_H
 #define OSMOSE_EMULATION_THREAD_H
 
diff --git a/src/OsmoseGUI.h b/src/OsmoseGUI.h
index 7c61cfa..a719483 100644
--- a/src/OsmoseGUI.h
+++ b/src/OsmoseGUI.h
@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *
  * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
@@ -18,15 +18,7 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- *
- * File : OsmoseGUI.h
- *
- * Description : This class is the main Application class. It contains
- * all QT objects and signal slots that are needed.
- *
- * Author : B.Vedder
- *
- * Date : Fri May 14 14:53:24 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
@@ -82,7 +74,7 @@ protected slots:
 	void sizeX2();
 	void sizeX3();
 	void sizeX4();
-    void fullscreen();
+    	void fullscreen();
 	void loadROM();
 	void pauseResumeEmulation();
 	void resetEmulation();
diff --git a/src/OsmoseResources.qrc b/src/OsmoseResources.qrc
index b46e983..22c9938 100644
--- a/src/OsmoseResources.qrc
+++ b/src/OsmoseResources.qrc
@@ -1,5 +1,5 @@
 <!DOCTYPE RCC><RCC version="1.0">
 <qresource>
-    <file>./osmose-emulator.xpm</file>
+    <file>./osmose-emulator.png</file>
 </qresource>
 </RCC>
diff --git a/src/Pthreadcpp.cpp b/src/Pthreadcpp.cpp
index 311af2b..f66004c 100644
--- a/src/Pthreadcpp.cpp
+++ b/src/Pthreadcpp.cpp
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,21 +17,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : Pthreadcpp.cpp
- *
- * Description :
  *
- * Author : B.Vedder
- *
- * Date : Fri Dec 17 07:44:27 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
 #include "Pthreadcpp.h"
 
-/**	
+/**
  * Description : This class is the most basic pthread C++ encapsulation.
  * It's used to handle JOINABLE / UNDETACHED posix threads.
  * To create a thread, simply inherit this class, and override the run()
diff --git a/src/Pthreadcpp.h b/src/Pthreadcpp.h
index 51bbad3..0cd9429 100644
--- a/src/Pthreadcpp.h
+++ b/src/Pthreadcpp.h
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,15 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : Pthreadcpp.h
- *
- * Description : This class provide basic Mutex and Thread C++ encapsulation.
- *
- * Author : B.Vedder
  *
- * Date : Fri Dec 17 07:44:27 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
diff --git a/src/QGLImage.cpp b/src/QGLImage.cpp
index aa556e3..5270031 100644
--- a/src/QGLImage.cpp
+++ b/src/QGLImage.cpp
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,29 +17,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : QGLImage.cpp
- *
- * Description : This Object is used to display image on an OpenGL
- * textured quad . If the QGLImage size changes, the texture will be stretched
- * to fit the Quad. The texture dimension can be changed, but should not
- * be done every frame, for performances reasons. Note that texture
- * format is fixed to 32 bits RGBA.
  *
- * The textureBuffer is protected by a mutex because blit() or 
- * resolutionChanged slot may be called during paintEvent. The blit() method
- * expect the source buffer to be of the current texture resolution.
- * 
- * The texture is refreshed using the blit() method, which call update().
- * Author : B.Vedder
- *
- * Date : Wed May 19 17:55:00 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
 #include "QGLImage.h"
 #include <iostream>
+#include <GL/gl.h>
+
+#define GL_UNSIGNED_INT_8_8_8_8_REV	0x8367
+#define GL_QUADS	0x0007
+#define GL_CLAMP	0x2900
+#define GL_MODELVIEW	0x1700
+#define GL_PROJECTION	0x1701
 
 using namespace std;
 
diff --git a/src/QGLImage.h b/src/QGLImage.h
index 0120fc5..d14175c 100644
--- a/src/QGLImage.h
+++ b/src/QGLImage.h
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,23 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : QGLImage.h
- *
- * Description : This Object is used to display image on an OpenGL
- * textured quad . If the QGLImage size changes, the texture will be stretched
- * to fit the Quad. The texture dimension can be changed, but should not
- * be done every frame, for performances reasons. Note that texture
- * format is fixed to 32 bits RGBA.
- *
- * The textureBuffer is protected by a mutex because blit() or 
- * resolutionChanged slot may be called during paintEvent. The blit() method
- * expect the source buffer to be of the current texture resolution.
- *
- * Author : B.Vedder
  *
- * Date : Wed May 19 17:55:00 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
diff --git a/src/QLogWindow.cpp b/src/QLogWindow.cpp
index 3b37417..21dc72c 100644
--- a/src/QLogWindow.cpp
+++ b/src/QLogWindow.cpp
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,15 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : QLogWindow.cpp
- *
- * Description :
- *
- * Author : B.Vedder
  *
- * Date : Sun Dec 12 08:33:30 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
diff --git a/src/QLogWindow.h b/src/QLogWindow.h
index 9cd95fd..8ceea3e 100644
--- a/src/QLogWindow.h
+++ b/src/QLogWindow.h
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,15 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : QLogWindow.h
- *
- * Description :
- *
- * Author : B.Vedder
  *
- * Date : Sun Dec 12 08:33:30 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
diff --git a/src/QOsmoseConfiguration.cpp b/src/QOsmoseConfiguration.cpp
index 9f13dac..b840fdd 100644
--- a/src/QOsmoseConfiguration.cpp
+++ b/src/QOsmoseConfiguration.cpp
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,18 +17,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : QOsmoseConfiguration.cpp
- *
- * Description :
  *
- * Author : B.Vedder
- *
- * Date : Sun Nov 21 16:21:21 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
+
 #include "QOsmoseConfiguration.h"
 #include <iostream>
 
diff --git a/src/QOsmoseConfiguration.h b/src/QOsmoseConfiguration.h
index ec627af..9b79a28 100644
--- a/src/QOsmoseConfiguration.h
+++ b/src/QOsmoseConfiguration.h
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,15 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- * File : QOsmoseConfiguration.h
- *
- * Description :
- *
- * Author : B.Vedder
  *
- * Date : Sun Nov 21 16:21:21 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
diff --git a/src/RomSpecificOption.cpp b/src/RomSpecificOption.cpp
index c9a53fd..629ddbe 100644
--- a/src/RomSpecificOption.cpp
+++ b/src/RomSpecificOption.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,19 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: RomSpecificOption.cpp
- *
- * Project: Osmose emulator.
- *
- * Description: This class will store ROM CRC32 and specific options for
- * rom that need them to run.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 22.11.2006 13:08:54
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #include "RomSpecificOption.h"
 #include "MemoryMapper.h"
 
diff --git a/src/RomSpecificOption.h b/src/RomSpecificOption.h
index b380de7..b61e1a9 100644
--- a/src/RomSpecificOption.h
+++ b/src/RomSpecificOption.h
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,19 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: RomSpecificOption.h
- *
- * Project: Osmose emulator.
- *
- * Description: This class will store ROM CRC32 and specific options for
- * rom that need them to run.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 22.11.2006 13:08:54
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #ifndef ROM_SPECIFIC_OPTION_H
 #define ROM_SPECIFIC_OPTION_H
 #include "Options.h"
diff --git a/src/SN76489.cpp b/src/SN76489.cpp
index 1370475..2ca4bef 100644
--- a/src/SN76489.cpp
+++ b/src/SN76489.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,20 +18,12 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: SN76489.cpp
- *
- * Project: Osmose emulator.
- *
- * Description: This class will implements SN76489 functionnality.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 18/11/2004, 18h00
- *
- * URL: http://bcz.asterope.fr
  */
+
 #include "SN76489.h"
 #include "Bits.h"
-//#include <stdio.h>
 
 /* Values ripped from MEKA. They've been controlled against a real SMS.*/
 const u16 SN76489::volume_table[16] = {892*5, 892*5, 892*5, 760*5, 623*5, 497*5, 404*5, 323*5, 257*5, 198*5, 159*5, 123*5,  96*5,  75*5,  60*5, 0};
diff --git a/src/SN76489.h b/src/SN76489.h
index 59da8bc..84f89b5 100644
--- a/src/SN76489.h
+++ b/src/SN76489.h
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,18 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: SN76489.h
- *
- * Project: Osmose emulator.
- *
- * Description: This class will define SN76489 interface.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 18/11/2004, 18h00
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #ifndef SN76489_H
 #define SN76489_H
 
diff --git a/src/SaveState.h b/src/SaveState.h
index 392958e..dabd0db 100644
--- a/src/SaveState.h
+++ b/src/SaveState.h
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,18 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: SaveState.h
- *
- * Project: Osmose emulator.
- *
- * Description: This class provide an interface for Savestate.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 27.11.2006 10:31:16
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #ifndef SAVESTATE_H
 #define SAVESTATE_H
 
diff --git a/src/SmsDebugger.cpp b/src/SmsDebugger.cpp
index 7881e2e..c17ce22 100644
--- a/src/SmsDebugger.cpp
+++ b/src/SmsDebugger.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,18 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: SmsDebugger.cpp
- *
- * Project: Osmose emulator.
- *
- * Description: This class will handle built-in debugger.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 16/10/2004, 18h00
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #include <iostream>
 #include <iomanip>
 #include "SmsDebugger.h"
diff --git a/src/SmsDebugger.h b/src/SmsDebugger.h
index 79d9f63..cd6fb00 100644
--- a/src/SmsDebugger.h
+++ b/src/SmsDebugger.h
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,18 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: SmsDebugger.h
- *
- * Project: Osmose emulator.
- *
- * Description: This class will handle built-in debugger.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 16/10/2004, 18h00
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #ifndef SMS_DEBUGGER_H
 #define SMS_DEBUGGER_H
 
diff --git a/src/SmsEnvironment.cpp b/src/SmsEnvironment.cpp
index 186662b..17359e9 100644
--- a/src/SmsEnvironment.cpp
+++ b/src/SmsEnvironment.cpp
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,11 +17,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
+ *
  */
- 
+
 #include <iostream>
 #include <iomanip> // for trace in hexa in rw port
-#include "./cpu/Z80.h"
+#include "Z80.h"
 #include "SmsEnvironment.h"
 
 using namespace std;
diff --git a/src/SmsEnvironment.h b/src/SmsEnvironment.h
index 06cdfb4..a2f0a28 100644
--- a/src/SmsEnvironment.h
+++ b/src/SmsEnvironment.h
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,6 +17,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
+ *
  */
  
 #ifndef SMS_ENVIRONMENT_H
@@ -24,7 +27,7 @@
 
 #include "Definitions.h"
 #include <iostream>
-#include "./cpu/Z80.h"
+#include "Z80.h"
 #include "MemoryMapper.h"
 #include "IOMapper.h"
 #include "IOMapper_GG.h"
diff --git a/src/SoundThread.cpp b/src/SoundThread.cpp
index 2aa30a9..4981591 100644
--- a/src/SoundThread.cpp
+++ b/src/SoundThread.cpp
@@ -1,6 +1,6 @@
-/**
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *
  * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
@@ -18,13 +18,7 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File : SoundThread.cpp
- *
- * Description :
- *
- * Author : B.Vedder
- *
- * Date : Wed Dec 15 07:43:05 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
diff --git a/src/SoundThread.h b/src/SoundThread.h
index 7c33e1c..f18a125 100644
--- a/src/SoundThread.h
+++ b/src/SoundThread.h
@@ -1,8 +1,8 @@
-/**
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,13 +18,7 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File : SoundThread.h
- *
- * Description :
- *
- * Author : B.Vedder
- *
- * Date : Wed Dec 15 07:43:05 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
diff --git a/src/TGAWriter.cpp b/src/TGAWriter.cpp
index 69d9cc9..46811c5 100644
--- a/src/TGAWriter.cpp
+++ b/src/TGAWriter.cpp
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,18 +17,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- *
- * File: TGAWriter.cpp
- * Project: Osmose
  *
- * Description: This file handle creation, and write into an uncompressed TGA
- * 24bits imagefile. No more formats supported.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 12/12/2007
- * URL: http://bcz.asterope.fr
  */
 
 #include "TGAWriter.h"
diff --git a/src/TGAWriter.h b/src/TGAWriter.h
index 21b632f..2c9a2d5 100644
--- a/src/TGAWriter.h
+++ b/src/TGAWriter.h
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,18 +17,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- *
- *
- * File: TGAWriter.h
- * Project: Osmose
  *
- * Description: This file handle creation, and write into an uncompressed TGA
- * 24bits imagefile. No more formats supported.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 12/12/2007
- * URL: http://bcz.asterope.fr
  */
 
 #ifndef TGA_WRITER_H
diff --git a/src/VDP.cpp b/src/VDP.cpp
index 7b557f1..44bc3db 100644
--- a/src/VDP.cpp
+++ b/src/VDP.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,18 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: VDP.cpp
- *
- * Project: Osmose emulator.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Description: This class will handle VDP (Video Display Processor)operation.
- *
- * Author: Vedder Bruno
- * Date: 11/10/2004, 08h30
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #include "VDP.h"
 
 extern Options opt;
diff --git a/src/VDP.h b/src/VDP.h
index cefec85..1a54a44 100644
--- a/src/VDP.h
+++ b/src/VDP.h
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,18 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: VDP_GG.h
- *
- * Project: Osmose emulator.
- *
- * Description: This class will handle SMS's VDP (Video Display Processor)operation.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 25/10/2006, 19h15
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #ifndef VDP_H
 #define VDP_H
 
diff --git a/src/VDP_GG.cpp b/src/VDP_GG.cpp
index 0455655..37d05a4 100644
--- a/src/VDP_GG.cpp
+++ b/src/VDP_GG.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,18 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: VDP_GG.cpp
- *
- * Project: Osmose emulator.
- *
- * Description: This class will handle GAMEGEAR's VDP (Video Display Processor)operation.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 25/10/2006, 19h15
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #include "VDP_GG.h"
 
 static unsigned color_latch = 0;
diff --git a/src/VDP_GG.h b/src/VDP_GG.h
index dcebd92..8462f5b 100644
--- a/src/VDP_GG.h
+++ b/src/VDP_GG.h
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,18 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: VDP_GG.h
- *
- * Project: Osmose emulator.
- *
- * Description: This class will handle GAMEGEAR's VDP (Video Display Processor)operation.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 25/10/2006, 19h15
- *
- * URL: http://bcz.asterope.fr/
  */
- 
+
 #ifndef VDP_GG_H
 #define VDP_GG_H
 
diff --git a/src/Version.h b/src/Version.h
index 53e511c..0cda132 100644
--- a/src/Version.h
+++ b/src/Version.h
@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *
  * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
@@ -17,6 +17,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
+ *
  */
 
 #ifndef VERSION_H
@@ -25,5 +28,5 @@
 // These four definitions should be coherent!
 #define __OSMOSE_VERSION__ "Osmose Emulator"
 #define MAJOR  1
-#define MIDDLE 0
+#define MIDDLE 1
 #endif
diff --git a/src/WaveWriter.cpp b/src/WaveWriter.cpp
index 55c789f..fb93ad3 100644
--- a/src/WaveWriter.cpp
+++ b/src/WaveWriter.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,19 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: WaveWriter.cpp
- *
- * Project: Osmose emulator.
- *
- * Description: This class implements waveWriter class used by Osmose for
- * saving sound. It's only designed to handle 16 bits mono 22050hz samples.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 25/11/2004, 14h00
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #include "WaveWriter.h"
 #include <cstdlib>
 
diff --git a/src/WaveWriter.h b/src/WaveWriter.h
index 5667777..148708a 100644
--- a/src/WaveWriter.h
+++ b/src/WaveWriter.h
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -18,19 +18,10 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- * File: waveWriter.h
- *
- * Project: Osmose emulator.
- *
- * Description: This class declares waveWriter class used by Osmose for
- * saving sound. It's only designed to handle 16 bits mono 22050hz samples.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 25/11/2004, 14h00
- *
- * URL: http://bcz.asterope.fr
  */
- 
+
 #ifndef WAVE_WRITER_H
 #define WAVE_WRITER_H
 
diff --git a/src/WhiteNoiseEmulationThread.cpp b/src/WhiteNoiseEmulationThread.cpp
index 400ce72..e352f98 100644
--- a/src/WhiteNoiseEmulationThread.cpp
+++ b/src/WhiteNoiseEmulationThread.cpp
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,15 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- * File : WhiteNoiseEmulationThread.cpp
- *
- * Description : This fake emulation thread is used to generate
- * white noise when no ROM is loaded.
- *
- * Author : B.Vedder
  *
- * Date : Sat Nov 13 11:38:27 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
diff --git a/src/WhiteNoiseEmulationThread.h b/src/WhiteNoiseEmulationThread.h
index 688bc71..194d7d3 100644
--- a/src/WhiteNoiseEmulationThread.h
+++ b/src/WhiteNoiseEmulationThread.h
@@ -1,8 +1,8 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,17 +17,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- *	
- * File : WhiteNoiseEmulationThread.h
- *
- * Description : This fake emulation thread is used to generate
- * white noise when no ROM is loaded.
  *
- * Author : B.Vedder
- *
- * Date : Sat Nov 13 11:38:27 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
+
 #ifndef WHITE_NOISE_EMULATION_THREAD_H
 #define WHITE_NOISE_EMULATION_THREAD_H
 
diff --git a/src/Z80.cpp b/src/Z80.cpp
index f8690ed..cdea53d 100644
--- a/src/Z80.cpp
+++ b/src/Z80.cpp
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,20 +17,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- * File: Z80.h
- *
- * Project: Osmose emulator.
  *
- * Description: This class implements Z80 cpu emulator. It's table driven, and all
- * opcodes are supported. Not that undocumented flags are not totaly supported.
- * In these files are defined almost all ALU, and Shift operations. Address mode
- * getters and setters are define in Z80.h as statics methods.
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * Author: Vedder Bruno
- * Date: 10/01/2006, Thailand, Laos Cambodia :-)
- *
- * URL: http://bcz.asterope.fr
- *****************************************************************************/
+ */
 
 #include "Z80.h"
 #include <stdio.h>
diff --git a/src/Z80.h b/src/Z80.h
index b40ab20..6a068be 100644
--- a/src/Z80.h
+++ b/src/Z80.h
@@ -1,8 +1,8 @@
-/*****************************************************************************
+/*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,18 +17,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
- * File: Z80.h
- *
- * Project: Osmose emulator.
- *
- * Description: This class defines Z80 cpu emulator. It's table driven, and all
- * opcodes are supported. Not that undocumented flags are not totaly supported.
- *
  *
- * Author: Vedder Bruno
- * Date: 10/01/2006, Thailand, Laos Cambodia :-)
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
- * URL: http://bcz.asterope.fr
  */
 
 #ifndef Z80_H_
diff --git a/src/main.cpp b/src/main.cpp
index ca9f7dd..faac269 100644
--- a/src/main.cpp
+++ b/src/main.cpp
@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *
  * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
@@ -18,6 +18,7 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 

diff --git a/src/OsmoseGUI.cpp b/src/OsmoseGUI.cpp
index 465d0c0..79c02e5 100644
--- a/src/OsmoseGUI.cpp
+++ b/src/OsmoseGUI.cpp
@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
  * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
  *
  * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
@@ -18,15 +18,7 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  *
- *
- * File : OsmoseGUI.cpp
- *
- * Description : This class is the main Application class. It contains
- * all QT objects and signal slots that are needed.
- *
- * Author : B.Vedder
- *
- * Date : Fri May 14 14:53:24 2010
+ * Many thanks to Vedder Bruno, the original author of Osmose Emulator.
  *
  */
 
@@ -34,6 +26,7 @@
 #include <QWidget>
 #include "OsmoseGUI.h"
 #include <QIcon>
+#include <QMimeData>
 
 /**
  * Constructor.
@@ -47,7 +40,7 @@ OsmoseGUI::OsmoseGUI(QWidget * parent, Qt::WindowFlags flags) : QMainWindow(pare
 	osmose_core_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 	this->setWindowTitle(__OSMOSE_VERSION__);
-	this->setWindowIcon(QIcon(":/osmose-emulator.xpm"));
+	this->setWindowIcon(QIcon(":/osmose-emulator.png"));
 
 	QLogWindow::getInstance()->appendLog("Starting Osmose emulator.");
 
@@ -314,7 +307,7 @@ OsmoseGUI::OsmoseGUI(QWidget * parent, Qt::WindowFlags flags) : QMainWindow(pare
 
 	// ABOUT Menu
 	menu = new QMenu("About", this);
-	action = new QAction("&About the emulator", this);
+	action = new QAction("&About emulator", this);
 	action->setShortcut(tr("F1"));
 	connect(action, &QAction::triggered, this, &OsmoseGUI::aboutDialog);
 	menu->addAction(action);
@@ -492,7 +485,7 @@ void OsmoseGUI::loadTheROM(QString filename)
 		bool killed = emuThread->wait(1000); // Wait for thread end for 1 second.
 		if (!killed)
 		{
-			string msg = "Warning : could not kill emulation thread !";
+			string msg = "Warning: could not kill emulation thread !";
 			QLogWindow::getInstance()->appendLog(msg);
 		}
 		delete emuThread;
@@ -954,12 +947,13 @@ void OsmoseGUI::aboutDialog()
 {
 	    QMessageBox::about(this,tr("About"), \
 	    tr("<center><b>OSMOSE EMULATOR</b></center> \
-	    \n<center><b>Version: 1.0</b></center> \
+	    \n<center><b>Version: 1.1</b></center> \
 	    \n<center><i>Sega Master System and Game Gear console emulator</i></center><br> \
-	    <b>Copyright holder: </b>©2001-2011 \
-	    <a href='mailto:bruno at asterope.fr'> Bruno Vedder</a><br>  \
-	    <b>Contributor: </b>©2016 \
-	    <a href='mailto:coringao at riseup.net'> Carlos Donizete Froes</a><br><br> \
+	    Many thanks to <b>Vedder Bruno</b> [2001-2011]\
+	    the original author of Osmose Emulator.<br>  \
+	    Work continued by <b>Carlos Donizete</b> [2016-2017]. \
+	    <br><br> \
 	    This program comes with absolutely no warranty and can be redistributed and/or \
-	    modified under the terms of the <a href='http://www.gnu.org/licenses/gpl.html'>GNU GPL versions 3 or later</a>.<br>"));
+	    modified under the terms of the \
+	    <a href='http://www.gnu.org/licenses/gpl.html'>GNU GPL versions 3 or later</a>.<br>"));
 }
@@ -1,6 +1,6 @@
 /*
  * Copyright holder 2001-2011 Vedder Bruno.
- * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ * Work continued by 2016-2017 Carlos Donizete Froes [a.k.a coringao]
  *
  * This file is part of Osmose, a Sega Master System/Game Gear software
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-games/osmose-emulator.git



More information about the Pkg-games-commits mailing list